% Discrete Brusselator
% 
% from the book "Practical bifurcation and stability analysis" by Seydel
% system : chemical reaction, 3 cells. See  Chapter 5, p 188)
%
%  Governing equations
%   2 - 7u1       + u1*u1*u2  +    lambda(u3-u1)     =0
%       6u1       - u1*u1*u2  + 10 lambda(u4-u2)     =0
%   2 - 7u3       + u3*u3*u4  +    lambda(u1+u5-2u3) =0
%       6u3       - u3*u3*u4  + 10 lambda(u2+u6-2u4) =0
%   2 - 7u5       + u5*u5*u6  +    lambda(u3-u5)     =0
%       6u5       - u5*u5*u6  + 10 lambda(u4+u6)     =0
%
%  Unknowns  U=[ u1  u2 ....  u6 lambda]  
 
close all
clear all

% a start point
%U0= [ 2.89   2.63   1.86   2.75   1.23   2.84   3.67 ]';


% an accurate start point near one of the bifurcation point lamda=1.535 u1=1.5705
    Ustart   = [   1.407447376223965e+00
                   2.864123497547940e+00
                   2.855112580201338e+00
                   2.679981637773596e+00
                   1.737440043574695e+00
                   2.809196096926757e+00
                   1.504882581731042e+00 ];
    Pertu= [ 1 1 1 1 1 1  1]';
    U0   = Ustart + 1e-10*Pertu;

Diamanlab('sys'   ,BRUSSELATOR(0), ...
          'U0value',U0,...
          'displayvariables',[7,1]);      % DiaMANLAB run

