% 
% ---------------------------------------------------------------------
% ELASTICA : the clamped-clamped case  with an axial compressive load
% ---------------------------------------------------------------------
% 
%   the state vector 
%   ----------------
%
%   Z(s)= [x(s) ; y(s) ; theta(s) ; m(s) ]  (Nz=4) on s = [0,1]
%
%   the differential-algebraic equation system (here an ODE system)
%   ------------------------------------------------------------------
%    
%   
%      x'   = cos(theta)  
%      y'   = sin(theta)  
%    theta' = m         
%       m'  = -4 pi^2 ( lambda*sin(theta) - Ry cos(theta) ) 
%
%
%    parameters :  mu=[  Ry ; C0 ] (Nmu=2) 
%    ------------------------------------------------
%
%    lambda : applied axial force at s=1
%    Ry  (unknown) transversal reaction at s=1
%    C0  (unknown) moment reaction at s=1
%
%    Boundary conditions  (Nbc=5)
%    -------------------
%    X(0)=0
%    y(0)=0 
%    theta(0)=0 
%    m(0)=2*pi*m0
%
%    y(1)=0
%    theta(1)=0
% 
%  ---------------------------------------------------------------------------------
clc
clear all

 Nz=4;       % size of the state vector Z
 Nmu= 2;     % parameters number
 Nbc= 6;     % boundary condition number
 
 Nelmt=4;    % element number
 Npoly=3;    % degre of polynomial interpolation
 
 L=1;
 s=0:L/(Npoly*Nelmt): L;
 x    = s ;
 
 amp=0.03;
 y    =amp*(-cos(2*pi*s)+1);
 theta=amp*(2*pi*sin(2*pi*s));
  m   =amp*(4*pi*pi*cos(2*pi*s)); 
  
% y    = zeros(1,Npoly*Nelmt+1);
% theta= zeros(1,Npoly*Nelmt+1);
% m    = zeros(1,Npoly*Nelmt+1);


 %Intitialization of the start solution U 
 Nzd =(Npoly*Nelmt+1)*Nz;
 Z0 = zeros(Nzd,1);
 Z0(1:Nz:Nzd)=x;
 Z0(2:Nz:Nzd)=y+ 0.0001;
 Z0(3:Nz:Nzd)=theta;
 Z0(4:Nz:Nzd)=m;

 mu0=[ 0 ; 2*pi*amp ];

 lambda0= 1;

 U0=[Z0 ; mu0 ; lambda0];
 ninc = Nzd+ Nmu + 1;   % number of discrete unknowns (size of U0)

%            lambda   y(l/4)           
 dispvars = [ninc  ( Npoly*1)*Nz+2;   ]; 
 Diamanlab('sys',BVPCOLLO(Nz,Nmu,Nbc,Nelmt,Npoly,ninc), 'order', 20, 'U0value',U0, 'displayvariables', dispvars); 
 
