% 
% ---------------------------------------------------------------------------
% ELASTICA : the clamped-free case with a line load fy pressed against a wall
% A zone contact is developing and the original length of the beam (L=1) is reduced
% to l, witch is now an unkown parameter.
% The reaction of the wall Ry is normal to the wall surface
% ---------------------------------------------------------------------------
% 
%   the state vector 
%   ----------------
%
%   Z(s)= [x(s) ; y(s) ; theta(s) ; m(s) ]  (Nz=4) on s = [0,1]
%
%   the differential-algebraic equation system (here an ODE system)
%   ------------------------------------------------------------------
%    
%   
%      x'   = l cos(theta)  
%      y'   = l sin(theta)  
%    theta' = l m         
%       m'  = -4 pi^2 l (Fx(s) sin(theta) -  Fy(s) cos(theta) ) = 0
%
%    with : Fx(s)=Ry*sin(theta(s=1))   and  Fy(s) = lambda*fy*(L-s)+ Rycos(theta(s=1))   
%
%    parameters :  mu=[ Ry ; l  ] (Nmu=2) 
%    ------------------------------
%
%    Boundary conditions  (Nbc=6)
%    -------------------
%    X(0)=0
%    y(0)=0 
%    theta(0)=0 
%
%    y(1)=-0.2
%    theta(1)=0
%    m(1)= 0 
%  ---------------------------------------------------------------------------------
clc
clear all

 Nz=  4;     % size of the state vector Z
 Nmu= 2;     % parameters number
 Nbc= 4;     % boundary condition number
 
 Nelmt=4;    % element number
 Npoly=3;    % degre of polynomial interpolation

 L=1.;

 s=0:1/(Npoly*Nelmt): 1;
 x    = s*L ;
 y    = zeros(1,Npoly*Nelmt+1);
 theta= zeros(1,Npoly*Nelmt+1);
 m    = zeros(1,Npoly*Nelmt+1);


 %Intitialization of the start solution U 
 Nzd =(Npoly*Nelmt+1)*Nz;
 Z0 = zeros(Nzd,1);
 Z0(1:Nz:Nzd)=x;
 Z0(2:Nz:Nzd)=y;
 Z0(3:Nz:Nzd)=theta+ 0.0000001;
 Z0(4:Nz:Nzd)=m;

 mu0=[ -1 ; 1. ];

 lambda0= 0;

 U0=[Z0 ; mu0 ; lambda0];
 ninc = Nzd+ Nmu + 1;   % number of discrete unknowns (size of U0)

%            lambda   y(1)        lambda   x(1)       lambda theta(1)   lambda  Fy   
 dispvars = [ninc   Nzd-Nz+2;   ninc   Nzd-Nz+1  ;   ninc  Nzd-Nz+3  ;  ninc  Nzd+1]; 
 Diamanlab('sys',BVPCOLLO(Nz,Nmu,Nbc,Nelmt,Npoly,ninc), 'order', 20, 'U0value',U0, 'displayvariables', dispvars); 
 
