classdef CheckPoint
% These objects are created along the continuation process,
% each time a new series is computed and stored.
% The main property is the series U0(a=0) stored in U0 and its range of utility [0, Amax].
% Other properties may be deduced from these two main properties
 properties
        
        % for storing the section       
        U0   =0;    % the start point + series      (taylor type)
        Ut   =0;    % traveling direction at start point   (vector)
        Amax =0;    % range of utility of series     
        Uend =0;    % the end point of the section  (vector)
        Utend=0;    % traveling direction at end      (vector)
        Upp  =0;    % U0 UI UII  ...  Uend, point by point representation of the section
                    %  Upp(ninc,nbpts)  nbpts: number of point per section
                    
        % for storing geometrical series and bifurcation data (when found )
        BifStatus='nothing';  % 'nothing' or 'simplebif ' 
        Ubif=0;       % bifurcation point
        Utf =0;       % tangent to the fondamental path
        Utb =0;       % tangent to the bifurcated path
        alpha=0;      % common ratio of the emerging geometrical series
        Uscale=0;     % scale vector of emerging geometrical series
        
        % for displaying the projected bifurcation diagram         
        dispcolors='';
        dispvars=0;
        drawtype=''
        markers=''
        nbpts=0;
        ncurve=0;      
        X=0;     % X coordinate of the point to be plotted on Proj Bif Diag
        Y=0;     % Y coordinate of the point to be plotted on Proj Bif Diag
        A=0;     % values a of the path variable of the point to be plotted
        Xbif=0;  % X coordinate of the bifurcation point (if one)
        Ybif=0;  % Y coordinate of the bifurcation point (if one)
        
 end
    
 methods
        
    function obj = CheckPoint(U0,Ut,Amax,params,BifData)
    % construct  CheckPoint object from the two main properties U0, Amax
    % and BifData
    global Ck
    
    % parameters
    obj.dispcolors  = params.dispcolors;
    obj.dispvars    = params.dispvars;
    obj.drawtype    = params.drawtype;
    obj.markers     = params.markers;
    obj.nbpts       = params.nbpts;
    obj.ncurve      = length(obj.dispvars(:,1));
    
   
    %  Section definition
    obj.U0    = U0;         % the start point + series      (taylor type)
    obj.Ut    = Ut;         % traveling direction at start    (vector)
    obj.Amax  = Amax;       % range of utility of series
    obj.A     = zeros(obj.nbpts,1);
    obj.Upp   = zeros(size(Ut,1),obj.nbpts) ;
    for p=1:obj.nbpts
        a = (p-1)/(obj.nbpts-1)*Amax;
        obj.A(p) = a;                           % store values a of the path variable 
        obj.Upp(:,p) = evalseries(U0,a,Ck); %  Upp = [U0 UI UII  ...  Uend]
    end   
    obj.Uend  = obj.Upp(:,obj.nbpts) ;             % the end point                  (vector)
    obj.Utend = evalderiv(U0,obj.Amax,Ck) ;    % traveling direction at end      (vector)
 
    % data for the projected bifurcation diagram

    obj.X = obj.Upp(obj.dispvars(:,1),:)';   % X coordinate of the point to be plotted on Proj Bif Diag
    obj.Y = obj.Upp(obj.dispvars(:,2),:)';   % Y coordinate of the point to be plotted on Proj Bif Diag
   
    % store data  bifurcation 

     switch BifData.status            
        case 'simplebif'           
            obj.BifStatus=BifData.status;
            obj.Ubif     =BifData.Ubif;
            obj.Utf      =BifData.Utf;
            obj.Utb      =BifData.Utb;
            obj.alpha    =BifData.alpha;
            obj.Uscale   =BifData.Uscale;
            
            obj.Xbif=obj.Ubif(obj.dispvars(:,1));
            obj.Ybif=obj.Ubif(obj.dispvars(:,2));           
     end    
    end
 end
end

