function [U0,Amax, BifData] = ANMseries(sys,U0val,Ut0)
% Compute ANM series for sys(U0val) 
% Outputs: U0 (taylor type), Amax (domaine of utility), 
% BifData is a structure variable used to store bifurcation point data
% when one is found  properties : Ubif,Utf, Utb,alpha,status

global Ck

  
dRdU = Jacobian(sys,U0val);       % Jacobian of sys w.r.t. U at point U0val
        
 

U1 = tangentvector(sys,U0val,dRdU);     % tangent vector at U0val
if (U1'*Ut0) < 0, U1 = - U1; end  % set U1 in the direction of Ut0

    %% ANM Tangent Matrix: Jacobian of sys w.r.t. U "+" Jacobian of the path equation, at point U0
    K = [dRdU ; (sys.arclengthdef.*U1)'];
  
    % Fast LU-factorization
    [LK,UK,pK,qK] = lu(K,'vector');

    %% series computation : Zero and First order

    U0=Taylor(get(sys,'order'),U0val);
    U0=set(U0,'coef1',U1);

    %% series computation : Orders p>=2 
    for p=2:sys.order
        Ck=p;
        Rhs=[-Fpnl(sys,U0,p);0] ;
        Usol(qK)=   UK\(LK\Rhs(pK)) ;
        U0=set(U0,'coefk',Usol,p); 
    end
    %% domaine of utility Amax       
    if (norm(Rhs)==0)
        Amax = 1;
        disp(' Infinite radius : Amax deliberately set to 1');
    else  
        Amax = (sys.ANMthreshold/norm(Rhs))^(1/(sys.order));       
    end
 
    
    %% Detection and extraction of emerging geometric series
    
    [Uclean, BifData.Uscale, BifData.alpha, BifData.status] = GeomSerie(sys, U0);
    
    switch BifData.status 
        case 'nothing'
        
        case 'simplebif'
        [BifData.Ubif, BifData.Utf, BifData.Utb]=locatebif(sys, Uclean, BifData.Uscale, BifData.alpha);
        U0=Uclean;
        Rhs_A=Fpnl(sys,U0,p); 
        Amax = (sys.ANMthreshold/norm(Rhs_A))^(1/(sys.order));  % recompute A_max
    end


