function [Ubif, Utf, Utb]=locatebif(sys, Uclean,Uscale,Alpha)
% locate a simple bifurcation point and its two tangents
% outputs : Ubif (bif point), Utf and Utb (the two tangents
% at Ubif along fondamental path and bifurcated path)
% inputs : Alpha (common ratio), Uscale (scale factor)
global Ck
Ck=sys.order;

Norder=get(sys, 'order');

Ubif=evalseries(Uclean,Alpha,Norder);  

dRdU=Jacobian(sys, Ubif);

Kt=dRdU(:,1:end-1)';
phi=Kt\ones(get(sys, 'neq'),1);
phi=phi/norm(phi);
phi=Kt\phi;
phi=phi/norm(phi);

%Utf: tangent of the fondamental path.
Utf=evalderiv(Uclean,Alpha,Norder);

%normalisation of Utf and Uscale
Utf=Utf/norm(Utf);
Uscale=Uscale/norm(Uscale);

%Computation of the second tangent at the biffurcation point
% a) Computation of ddRddU_Utb(Uscale,Uscale)
Utemp=Taylor(Norder,Ubif);
Utemp1=set(Utemp,'coef1',Uscale); % Initialization of first derivative U1 to Utf
Utemp1=set(Utemp1,'coefk',zeros(size(Utf)),2);
ddRUdd_UU=Fpnl(sys,Utemp1,2);

% b) computation of ddRddU(Utf-Uscale) and ddRddU(Utf+Uscale)
Vtemp=set(Utemp1, 'coef1', Utf + Uscale);
Wtemp=set(Utemp1, 'coef1', Utf - Uscale);
ddRUdd_UV=(Fpnl(sys,Vtemp,2)-Fpnl(sys,Wtemp,2))./2;

Utb=Utf-(phi'*ddRUdd_UV)/(phi'*ddRUdd_UU)*Uscale;
Utb=Utb/norm(Utb);

% check accuracy of the results
Rbif=R(sys,Ubif);
Rtf=dRdU*Utf;
Rtb=dRdU*Utb;
%phi'*Q(sys,Utf,Utf)
Utemp1=set(Utemp1,'coef1',Utf);
eqbiff=phi'*Fpnl(sys,Utemp1,2);
%phi'*Q(sys,Utb,Utb)
Utemp1=set(Utemp1,'coef1',Utb);
eqbifb=phi'*Fpnl(sys,Utemp1,2);

disp(['Bif info: ||R(Ubif)||=' num2str(norm(Rbif)) ' ||phi||=' num2str(norm(phi))]);
disp(['Tangent fond: ||dRdU(Utf)||= ' num2str(norm(Rtf)) ' ||Utf||= ' num2str(norm(Utf))]);
disp(['Tangent bif : ||dRdU(Utb)||= ' num2str(norm(Rtb)) ' ||Utb||= ' num2str(norm(Utb))]);
disp(['Bif info: TPhi.Q(Utf,Utf)= ' num2str(eqbiff) ' TPhi.Q(Utb, Utb)= ' num2str(eqbifb)]);

